@@ -106,6 +106,7 @@ impl<S, A> ArrayBase<S, Ix2>
     }
 }
 
+#[cfg(not(debug_assertions))]
 macro_rules! size_checked_unwrap {
     ($dim:expr) => {
         match $dim.size_checked() {
@@ -115,6 +116,17 @@ macro_rules! size_checked_unwrap {
     }
 }
 
+#[cfg(debug_assertions)]
+macro_rules! size_checked_unwrap {
+    ($dim:expr) => {
+        match $dim.size_checked() {
+            Some(sz) => sz,
+            None => panic!("ndarray: Shape too large, number of elements overflows usize in shape {:?}",
+                           $dim),
+        }
+    }
+}
+
 /// ## Constructor methods for n-dimensional arrays.
 ///
 /// The `shape` argument can be an integer or a tuple of integers to specify
