@@ -144,6 +144,15 @@ impl<A, S, D> ArrayBase<S, D> where S: Data<Elem=A>, D: Dimension
         self.to_owned().into_shared()
     }
 
+    /// Turn the array into a uniquely owned array, cloning the array elements
+    /// to unshare them if necessary.
+    pub fn into_owned(self) -> Array<A, D>
+        where A: Clone,
+              S: DataOwned,
+    {
+        S::into_owned(self)
+    }
+
     /// Turn the array into a shared ownership (copy on write) array,
     /// without any copying.
     pub fn into_shared(self) -> RcArray<A, D>
@@ -275,10 +284,18 @@ impl<A, S, D> ArrayBase<S, D> where S: Data<Elem=A>, D: Dimension
     /// ```
     pub fn get<I>(&self, index: I) -> Option<&A>
         where I: NdIndex<D>,
+    {
+        unsafe {
+            self.get_ptr(index).map(|ptr| &*ptr)
+        }
+    }
+
+    pub(crate) fn get_ptr<I>(&self, index: I) -> Option<*const A>
+        where I: NdIndex<D>,
     {
         let ptr = self.ptr;
         index.index_checked(&self.dim, &self.strides)
-             .map(move |offset| unsafe { &*ptr.offset(offset) })
+             .map(move |offset| unsafe { ptr.offset(offset) as *const _ })
     }
 
     /// Return a mutable reference to the element at `index`, or return `None`
@@ -287,9 +304,20 @@ impl<A, S, D> ArrayBase<S, D> where S: Data<Elem=A>, D: Dimension
         where S: DataMut,
               I: NdIndex<D>,
     {
+        unsafe {
+            self.get_ptr_mut(index).map(|ptr| &mut *ptr)
+        }
+    }
+
+    pub(crate) fn get_ptr_mut<I>(&mut self, index: I) -> Option<*mut A>
+        where S: DataMut,
+              I: NdIndex<D>,
+    {
+        // const and mut are separate to enforce &mutness as well as the
+        // extra code in as_mut_ptr
         let ptr = self.as_mut_ptr();
         index.index_checked(&self.dim, &self.strides)
-             .map(move |offset| unsafe { &mut *ptr.offset(offset) })
+             .map(move |offset| unsafe { ptr.offset(offset) })
     }
 
     /// Perform *unchecked* array indexing.
@@ -1611,7 +1639,7 @@ impl<A, S, D> ArrayBase<S, D> where S: Data<Elem=A>, D: Dimension
               F: FnMut(ArrayView1<'a, A>) -> B,
               A: 'a,
     {
-        let view_len = self.shape().axis(axis);
+        let view_len = self.len_of(axis);
         let view_stride = self.strides.axis(axis);
         // use the 0th subview as a map to each 1d array view extended from
         // the 0th element.
