@@ -16,11 +16,11 @@
 //! dimensions, then an element in the array is accessed by using that many indices.
 //! Each dimension is also called an *axis*.
 //!
-//! - [**`ArrayBase`**](struct.ArrayBase.html):
+//! - **[`ArrayBase`](struct.ArrayBase.html)**:
 //!   The *n*-dimensional array type itself.<br>
 //!   It is used to implement both the owned arrays and the views; see its docs
-//!   for an overview of all array features.  
-//! - The main specific array type is [**`Array`**](type.Array.html), which owns
+//!   for an overview of all array features.<br>
+//! - The main specific array type is **[`Array`](type.Array.html)**, which owns
 //! its elements.
 //!
 //! ## Highlights
@@ -115,6 +115,7 @@ pub use linalg_traits::{LinalgScalar, NdFloat};
 pub use stacking::stack;
 
 pub use shape_builder::{ ShapeBuilder};
+pub use impl_views::IndexLonger;
 
 #[macro_use] mod macro_utils;
 #[macro_use] mod private;
@@ -427,6 +428,7 @@ pub type Ixs = isize;
 /// The slicing argument can be passed using the macro [`s![]`](macro.s!.html),
 /// which will be used in all examples. (The explicit form is a reference
 /// to a fixed size array of [`Si`]; see its docs for more information.)
+///
 /// [`Si`]: struct.Si.html
 ///
 /// ```
@@ -529,6 +531,8 @@ pub type Ixs = isize;
 ///
 /// Since the trait implementations are hard to overview, here is a summary.
 ///
+/// ### Binary Operators with Two Arrays
+///
 /// Let `A` be an array or view of any kind. Let `B` be an array
 /// with owned storage (either `Array` or `RcArray`).
 /// Let `C` be an array with mutable data (either `Array`, `RcArray`
@@ -542,6 +546,8 @@ pub type Ixs = isize;
 /// - `B @ &A` which consumes `B`, updates it with the result, and returns it
 /// - `C @= &A` which performs an arithmetic operation in place
 ///
+/// ### Binary Operators with Array and Scalar
+///
 /// The trait [`ScalarOperand`](trait.ScalarOperand.html) marks types that can be used in arithmetic
 /// with arrays directly. For a scalar `K` the following combinations of operands
 /// are supported (scalar can be on either the left or right side, but
@@ -551,6 +557,15 @@ pub type Ixs = isize;
 /// - `B @ K` or `K @ B` which consumes `B`, updates it with the result and returns it
 /// - `C @= K` which performs an arithmetic operation in place
 ///
+/// ### Unary Operators
+///
+/// Let `A` be an array or view of any kind. Let `B` be an array with owned
+/// storage (either `Array` or `RcArray`). The following operands are supported
+/// for an arbitrary unary operator denoted by `@` (it can be `-` or `!`).
+///
+/// - `@&A` which produces a new `Array`
+/// - `@B` which consumes `B`, updates it with the result, and returns it
+///
 /// ## Broadcasting
 ///
 /// Arrays support limited *broadcasting*, where arithmetic operations with
