@@ -11,6 +11,7 @@ use ndarray::Si;
 use ndarray::{Ix, Ixs};
 
 use std::fmt;
+use std::ops::Neg;
 use num_traits::Float;
 
 fn test_oper(op: &str, a: &[f32], b: &[f32], c: &[f32])
@@ -18,21 +19,24 @@ fn test_oper(op: &str, a: &[f32], b: &[f32], c: &[f32])
     let aa = rcarr1(a);
     let bb = rcarr1(b);
     let cc = rcarr1(c);
-    test_oper_arr(op, aa.clone(), bb.clone(), cc.clone());
+    test_oper_arr::<f32, _>(op, aa.clone(), bb.clone(), cc.clone());
     let dim = (2, 2);
     let aa = aa.reshape(dim);
     let bb = bb.reshape(dim);
     let cc = cc.reshape(dim);
-    test_oper_arr(op, aa.clone(), bb.clone(), cc.clone());
+    test_oper_arr::<f32, _>(op, aa.clone(), bb.clone(), cc.clone());
     let dim = (1, 2, 1, 2);
     let aa = aa.reshape(dim);
     let bb = bb.reshape(dim);
     let cc = cc.reshape(dim);
-    test_oper_arr(op, aa.clone(), bb.clone(), cc.clone());
+    test_oper_arr::<f32, _>(op, aa.clone(), bb.clone(), cc.clone());
 }
 
-fn test_oper_arr<A: NdFloat + fmt::Debug, D: ndarray::Dimension>
-    (op: &str, mut aa: RcArray<A,D>, bb: RcArray<A, D>, cc: RcArray<A, D>)
+fn test_oper_arr<A, D>(op: &str, mut aa: RcArray<A, D>, bb: RcArray<A, D>, cc: RcArray<A, D>)
+where
+    A: NdFloat,
+    for<'a> &'a A: Neg<Output=A>,
+    D: Dimension,
 {
     match op {
         "+" => {
@@ -61,6 +65,7 @@ fn test_oper_arr<A: NdFloat + fmt::Debug, D: ndarray::Dimension>
             assert_eq!(aa, cc);
         },
         "neg" => {
+            assert_eq!(-&aa, cc);
             assert_eq!(-aa.clone(), cc);
         },
         _ => panic!()
@@ -328,6 +333,18 @@ fn reference_mat_vec_mul<A, S, S2>(lhs: &ArrayBase<S, Ix2>, rhs: &ArrayBase<S2,
         .into_shape(m).unwrap()
 }
 
+// simple, slow, correct (hopefully) mat mul
+fn reference_vec_mat_mul<A, S, S2>(lhs: &ArrayBase<S, Ix1>, rhs: &ArrayBase<S2, Ix2>)
+    -> Array1<A>
+    where A: LinalgScalar,
+          S: Data<Elem=A>,
+          S2: Data<Elem=A>,
+{
+    let (m, (_, n)) = (lhs.dim(), rhs.dim());
+    reference_mat_mul(&lhs.to_owned().into_shape((1, m)).unwrap(), rhs)
+        .into_shape(n).unwrap()
+}
+
 #[test]
 fn mat_mul() {
     let (m, n, k) = (8, 8, 8);
@@ -703,3 +720,45 @@ fn gen_mat_vec_mul() {
         }
     }
 }
+
+#[test]
+fn vec_mat_mul() {
+    let sizes = vec![(4, 4),
+                     (8, 8),
+                     (17, 15),
+                     (4, 17),
+                     (17, 3),
+                     (19, 18),
+                     (16, 17),
+                     (15, 16),
+                     (67, 63),
+        ];
+    // test different strides
+    for &s1 in &[1, 2, -1, -2] {
+        for &s2 in &[1, 2, -1, -2] {
+            for &(m, n) in &sizes {
+                for &rev in &[false, true] {
+                    let mut b = range_mat64(m, n);
+                    if rev {
+                        b = b.reversed_axes();
+                    }
+                    let (m, n) = b.dim();
+                    let a = range1_mat64(m);
+                    let mut c = range1_mat64(n);
+                    let mut answer = c.clone();
+
+                    {
+                        let b = b.slice(s![..;s1, ..;s2]);
+                        let a = a.slice(s![..;s1]);
+
+                        let answer_part = reference_vec_mat_mul(&a, &b);
+                        answer.slice_mut(s![..;s2]).assign(&answer_part);
+
+                        c.slice_mut(s![..;s2]).assign(&a.dot(&b));
+                    }
+                    assert_close(c.view(), answer.view());
+                }
+            }
+        }
+    }
+}
